.. _github-stats-3-6-0:

GitHub statistics for 3.6.0 (Sep 15, 2022)
==========================================

GitHub statistics for 2021/11/16 (tag: v3.5.0) - 2022/09/15

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 202 issues and merged 894 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/65?closed=1>`__

The following 174 authors contributed 4425 commits.

* Abhishek K M
* Adeel Hassan
* agra
* Aitik Gupta
* ambi7
* Andras Deak
* Andres Martinez
* Andrew Fennell
* andrzejnovak
* Andrés Martínez
* Anna Mastori
* AnnaMastori
* Ante Sikic
* Antony Lee
* arndRemy
* Ben Root
* Biswapriyo Nath
* cavesdev
* Clément Phan
* Clément Walter
* code-review-doctor
* Connor Cozad
* Constantine Evans
* Croadden
* daniilS
* Danilo Palumbo
* David Gilbertson
* David Ketcheson
* David Matos
* David Poznik
* David Stansby
* Davide Sandonà
* dependabot[bot]
* dermasugita
* Diego Solano
* Dimitri Papadopoulos
* dj4t9n
* Dmitriy Fishman
* DWesl
* Edouard Berthe
* eindH
* Elliott Sales de Andrade
* Eric Firing
* Eric Larson
* Eric Prestat
* Federico Ariza
* Felix Nößler
* Fernando
* Gajendra Pal
* gajendra0180
* GavinZhang
* Greg Lucas
* hannah
* Hansin Ahuja
* Harshal Prakash Patankar
* Hassan Kibirige
* Haziq Khurshid
* Henry
* henrybeUM
* Hood
* Hood Chatham
* Ian Hunt-Isaak
* Ian Thomas
* igurin-invn
* ikhebgeenaccount
* Isha Mehta
* Jake Bowhay
* Jake Li
* Jake Lishman
* Jake VanderPlas
* Jakub Klus
* James Tocknell
* Jan-Hendrik Müller
* Jay Joshi
* Jay Stanley
* jayjoshi112711
* Jeff Beck
* Jody Klymak
* Joel Frederico
* Joseph Fox-Rabinovitz
* Josh Soref
* Jouni K. Seppänen
* Kayran Schmidt
* kdpenner
* Kian Eliasi
* Kinshuk Dua
* kislovskiy
* KIU Shueng Chuan
* kjain
* kolibril13
* krassowski
* Krish-sysadmin
* Leeh Peter
* lgfunderburk
* Liam Toney
* Lucas Ricci
* Luke Davis
* luz paz
* mackopes
* MAKOMO
* MalikIdreesHasa
* Marcin Swaltek
* Mario
* Mario Sergio Valdés Tresanco
* martinRenou
* Matthew Feickert
* Matthias Bussonnier
* Mauricio Collares
* MeeseeksMachine
* melissawm
* Mr-Milk
* Navid C. Constantinou
* Nickolaos Giannatos
* Nicolas P. Rougier
* Niyas Sait
* noatamir
* ojeda-e
* Olivier Gauthé
* Oscar Gustafsson
* patquem
* Philipp Rohde
* Pieter Eendebak
* Pieter P
* Péter Leéh
* Qijia Liu
* Quentin Peter
* Raphael Quast
* rditlar9
* Richard Penney
* richardsheridan
* Rike-Benjamin Schuppner
* Robert Cimrman
* Roberto Toro
* root
* Ruth Comer
* Ruth G. N
* Ruth Nainggolan
* Ryan May
* Rémi Achard
* SaumyaBhushan
* Scott Jones
* Scott Shambaugh
* selormtamakloe
* Simon Hoxbro
* skywateryang
* Stefanie Molin
* Steffen Rehberg
* stone
* Sven Eschlbeck
* sveneschlbeck
* takimata
* tfpf
* Thomas A Caswell
* Tim Hoffmann
* Tobias Megies
* Tomas Hrnciar
* Tomasz Kuliński
* trichter
* unknown
* Uwe Hubert
* vfdev-5
* Vishal Chandratreya
* Vishal Pankaj Chandratreya
* Vishnu V K
* vk0812
* Vlad Korolev
* Will Qian
* William Qian
* wqh17101
* wsykala
* yaaun
* Yannic Schroeder
* yuanx749
* 渡邉 美希

GitHub issues and pull requests:

Pull Requests (894):

* :ghpull:`23814`: Consolidate release notes for 3.6
* :ghpull:`23899`: Backport PR #23885 on branch v3.6.x (DOC: Rearrange navbar-end elements)
* :ghpull:`23898`: Backport PR #23892 on branch v3.6.x (DOC: Fix docs for linestyles in contour)
* :ghpull:`23885`: DOC: Rearrange navbar-end elements
* :ghpull:`23894`: Backport PR #23881 on branch v3.6.x (Fix Pillow compatibility in example)
* :ghpull:`23897`: Backport PR #23887 on branch v3.6.x (Add missing label argument to barh docs)
* :ghpull:`23892`: DOC: Fix docs for linestyles in contour
* :ghpull:`23887`: Add missing label argument to barh docs
* :ghpull:`23893`: Backport PR #23886 on branch v3.6.x (CI: prefer (older) binaries over (newer) sdists)
* :ghpull:`23881`: Fix Pillow compatibility in example
* :ghpull:`23886`: CI: prefer (older) binaries over (newer) sdists
* :ghpull:`23880`: Backport PR #23862 on branch v3.6.x (Remove triggering of deprecation warning in AnchoredEllipse)
* :ghpull:`23862`: Remove triggering of deprecation warning in AnchoredEllipse
* :ghpull:`23879`: Backport PR #23864 on branch v3.6.x (Correct and improve documentation for anchored artists)
* :ghpull:`23877`: Backport PR #23841 on branch v3.6.x (clarified that hist computes histogram on unbinned data)
* :ghpull:`23872`: Backport PR #23871 on branch v3.6.x (DOC: Fix formatting of pick event demo example)
* :ghpull:`23841`: clarified that hist computes histogram on unbinned data
* :ghpull:`23864`: Correct and improve documentation for anchored artists
* :ghpull:`23871`: DOC: Fix formatting of pick event demo example
* :ghpull:`23869`: Backport PR #23867 on branch v3.6.x (DOC: fix deprecation warnings in examples)
* :ghpull:`23867`: DOC: fix deprecation warnings in examples
* :ghpull:`23858`: Backport PR #23855 on branch v3.6.x (DOC: fix deprecation warnings)
* :ghpull:`23859`: Backport PR #23844 on branch v3.6.x (Further improve dev setup instructions)
* :ghpull:`23844`: Further improve dev setup instructions
* :ghpull:`23855`: DOC: fix deprecation warnings
* :ghpull:`23854`: Backport PR #23852 on branch v3.6.x (Fix cross-compiling internal freetype)
* :ghpull:`23852`: Fix cross-compiling internal freetype
* :ghpull:`23853`: Backport PR #23830 on branch v3.6.x (Start testing on Python 3.11)
* :ghpull:`23830`: Start testing on Python 3.11
* :ghpull:`23851`: Backport PR #23850 on branch v3.6.x (removed single word in documenting doc)
* :ghpull:`23850`: removed single word in documenting doc
* :ghpull:`23848`: Backport PR #23843 on branch v3.6.x (Clarify that pycairo>=1.14.0 is needed.)
* :ghpull:`23843`: Clarify that pycairo>=1.14.0 is needed.
* :ghpull:`23842`: Backport PR #23840 on branch v3.6.x (Remove documentation for axes_grid)
* :ghpull:`23838`: Backport PR #23834 on branch v3.6.x (Revert "Refactor handling of tick and ticklabel visibility in Axis.clear")
* :ghpull:`23840`: Remove documentation for axes_grid
* :ghpull:`23837`: Backport PR #23833 on branch v3.6.x (Remove search field from sidebar)
* :ghpull:`23836`: Backport PR #23823 on branch v3.6.x ([DOC] Improve dev setup description)
* :ghpull:`23834`: Revert "Refactor handling of tick and ticklabel visibility in Axis.clear"
* :ghpull:`23833`: Remove search field from sidebar
* :ghpull:`23823`: [DOC] Improve dev setup description
* :ghpull:`23822`: Backport PR #23813 on branch v3.6.x (Triplot duplicated label)
* :ghpull:`23813`: Triplot duplicated label
* :ghpull:`23811`: Backport PR #23805 on branch v3.6.x (sphinxext: Do not copy plot_directive.css's metadata)
* :ghpull:`23805`: sphinxext: Do not copy plot_directive.css's metadata
* :ghpull:`23800`: Backport PR #23785 on branch v3.6.x (FIX: ensure type stability for missing cmaps in ``set_cmap``)
* :ghpull:`23799`: Backport PR #23790 on branch v3.6.x (DOC: Add cache busting to all static assets)
* :ghpull:`23785`: FIX: ensure type stability for missing cmaps in ``set_cmap``
* :ghpull:`23790`: DOC: Add cache busting to all static assets
* :ghpull:`23791`: Backport PR #23774 on branch v3.6.x (Correct rcParams-name in AutoDateFormatter doc-string)
* :ghpull:`23792`: Backport PR #23781 on branch v3.6.x (ci: Add plot types to sphinx-gallery artifacts)
* :ghpull:`23789`: Backport PR #23786 on branch v3.6.x (DOC: fontfallback works for most of the backends)
* :ghpull:`23788`: Backport PR #23784 on branch v3.6.x (DOC: Fix num2date docstring)
* :ghpull:`23786`: DOC: fontfallback works for most of the backends
* :ghpull:`23784`: DOC: Fix num2date docstring
* :ghpull:`23781`: ci: Add plot types to sphinx-gallery artifacts
* :ghpull:`23783`: Backport PR #23782 on branch v3.6.x (Remove ``Axes.cla`` from examples)
* :ghpull:`23782`: Remove ``Axes.cla`` from examples
* :ghpull:`23774`: Correct rcParams-name in AutoDateFormatter doc-string
* :ghpull:`23773`: Backport PR #23772 on branch v3.6.x (3d plots what's new cleanups)
* :ghpull:`23772`: 3d plots what's new cleanups
* :ghpull:`23765`: Backport PR #23762 on branch v3.6.x (FIX: legend handler warning too liberal)
* :ghpull:`23762`: FIX: legend handler warning too liberal
* :ghpull:`23759`: Backport PR #23686 on branch v3.6.x (Improve matplotlib.pyplot importtime by caching ArtistInspector)
* :ghpull:`23686`: Improve matplotlib.pyplot importtime by caching ArtistInspector
* :ghpull:`23756`: Backport PR #23569 on branch v3.6.x (Fix hidden xlabel bug in colorbar)
* :ghpull:`23755`: Backport PR #23742 on branch v3.6.x (FIX: unbreak ipympl)
* :ghpull:`23569`: Fix hidden xlabel bug in colorbar
* :ghpull:`23742`: FIX: unbreak ipympl
* :ghpull:`23752`: Backport PR #23750 on branch v3.6.x (Fix rcParams documentation)
* :ghpull:`23749`: Backport PR #23735 on branch v3.6.x (Correctly handle Axes subclasses that override cla)
* :ghpull:`23735`: Correctly handle Axes subclasses that override cla
* :ghpull:`23748`: Backport PR #23746 on branch v3.6.x (DOC: add numpydoc docstring + commentary to Axis.get_ticklocs)
* :ghpull:`23747`: Backport PR #23721 on branch v3.6.x (3d plot view angle documentation)
* :ghpull:`23746`: DOC: add numpydoc docstring + commentary to Axis.get_ticklocs
* :ghpull:`23721`: 3d plot view angle documentation
* :ghpull:`23744`: Backport PR #23740 on branch v3.6.x (Clarify error for colorbar with unparented mappable)
* :ghpull:`23741`: Backport PR #23674 on branch v3.6.x (Re-rename builtin seaborn styles to not include a dot.)
* :ghpull:`23740`: Clarify error for colorbar with unparented mappable
* :ghpull:`23674`: Re-rename builtin seaborn styles to not include a dot.
* :ghpull:`23738`: Backport PR #23639 on branch v3.6.x (Adding the new contributor meeting)
* :ghpull:`23739`: Backport PR #23712 on branch v3.6.x (FIX: do not try to help CPython with garbage collection)
* :ghpull:`23712`: FIX: do not try to help CPython with garbage collection
* :ghpull:`23639`: Adding the new contributor meeting
* :ghpull:`23732`: Backport PR #23729 on branch v3.6.x (Use cleaner recursion check in PyQt FigureCanvas' resizeEvent.)
* :ghpull:`23734`: Backport PR #23733 on branch v3.6.x (DOC: Update theme configuration for upcoming changes)
* :ghpull:`23733`: DOC: Update theme configuration for upcoming changes
* :ghpull:`23728`: Backport PR #23722 on branch v3.6.x (Restore deprecation class aliases in cbook)
* :ghpull:`23729`: Use cleaner recursion check in PyQt FigureCanvas' resizeEvent.
* :ghpull:`23726`: Backport PR #23711 on branch v3.6.x (Fix deprecation messages for vendoring unused things)
* :ghpull:`23722`: Restore deprecation class aliases in cbook
* :ghpull:`23727`: Backport PR #23724 on branch v3.6.x (Fix/harmonize spacing in dependencies.rst.)
* :ghpull:`23724`: Fix/harmonize spacing in dependencies.rst.
* :ghpull:`23711`: Fix deprecation messages for vendoring unused things
* :ghpull:`23715`: Backport PR #23708 on branch v3.6.x (Loosen up test_Normalize test)
* :ghpull:`23713`: Backport PR #23710 on branch v3.6.x (Fix cmap deprecations)
* :ghpull:`23708`: Loosen up test_Normalize test
* :ghpull:`23710`: Fix cmap deprecations
* :ghpull:`23696`: Backport PR #23695 on branch v3.6.x (Document polar handling of _interpolation_steps.)
* :ghpull:`23706`: Backport PR #23705 on branch v3.6.x (DOC: Added link to class under discussion)
* :ghpull:`23705`: DOC: Added link to class under discussion
* :ghpull:`23695`: Document polar handling of _interpolation_steps.
* :ghpull:`23668`: Api deprecate cmap functions
* :ghpull:`23049`: Add ``minor`` keyword argument to ``plt.x/yticks``
* :ghpull:`23665`: Harmonize docstrings for boxstyle/connectionstyle/arrowstyle.
* :ghpull:`23636`: FIX: macosx flush_events should process all events
* :ghpull:`23555`: Uncamelcase offsetTrans in draw_path_collection.
* :ghpull:`23682`: Fix generated documentation for deprecated modules
* :ghpull:`23678`: Get rcParams from mpl
* :ghpull:`23571`: Simplify _bind_draw_path_function.
* :ghpull:`23673`: DOC: Highlight information about avoiding labels in legend
* :ghpull:`22506`: Replace MathtextBackend mechanism.
* :ghpull:`23340`: Set correct path for Arc
* :ghpull:`23562`: Fix issue with get_edgecolor and get_facecolor in 3D plots
* :ghpull:`23634`: make.bat: Don't override SPHINXOPTS/O from the environment
* :ghpull:`23675`: Deprecate helper functions in axis3d
* :ghpull:`23676`: MNT: Get rcParams from mpl
* :ghpull:`23677`: TST: Use article class when checking for pgf
* :ghpull:`23669`: CI: Azure update from ubuntu-18.04 to ubuntu-latest and ubuntu-20.04
* :ghpull:`23670`: Add bar color demo.
* :ghpull:`23644`: Standardize edge-on axis locations when viewing primary 3d axis planes
* :ghpull:`23563`: Fix issue with drawing 3D lines where points are from nparray
* :ghpull:`23666`: MNT: Deprecate macosx prepare subplots tool
* :ghpull:`23572`: Deprecate ``get_grid_positions(..., raw=True)``.
* :ghpull:`23525`: Add functionality to label individual bars with Axes.bar()
* :ghpull:`23667`: Fix flake8 errors introduced by crossed PRs
* :ghpull:`23554`: MNT: Remove unused imports
* :ghpull:`23659`: Simplify/fix save_diff_image.
* :ghpull:`23663`: Small cleanups to _find_fonts_by_props.
* :ghpull:`23662`: Add tolerance to test failing on ppc64le
* :ghpull:`23623`: MNT: remove _gridspecs attribute on Figure classes
* :ghpull:`23654`: Reverts macosx change to ARC
* :ghpull:`23661`: Remove unused fontsize argument from private mathtext _get_info.
* :ghpull:`23655`: Merge branch v3.5.x into main
* :ghpull:`23658`: Increase tolerance on multi-font tests
* :ghpull:`23657`: Add eps to extension list in image triager
* :ghpull:`23656`: Fix broken link to MathML torture tests.
* :ghpull:`23649`: CI: Use anaconda-client v1.10.0 for upload of nightlies
* :ghpull:`23647`: Allow any color format to be used for axis3d.Axis.set_pane_color
* :ghpull:`23643`: Enable wheels for PyPy 3.8+
* :ghpull:`23621`: DOC: update and extend fonts explanation
* :ghpull:`23612`: CI: try installing a different version of noto on OSX
* :ghpull:`23619`: add pikepdf  and visual c++ dependency
* :ghpull:`23631`: Leave out ``barh`` from the basic plot types.
* :ghpull:`23637`: BLD: Add Python 3.11 builds to CI
* :ghpull:`23632`: Add discouraged admonitions
* :ghpull:`23620`: Doc update deps
* :ghpull:`23627`: Bump pypa/cibuildwheel from 2.8.1 to 2.9.0
* :ghpull:`23628`: Change Title Case to Upper lower in templates
* :ghpull:`23206`: Change exception type for incorrect SVG date metadata
* :ghpull:`23387`: Remove setuptools_scm_git_archive dependency and add sdist test
* :ghpull:`23605`: Fix issues in examples, docs, and tutorials
* :ghpull:`23618`: [Doc]: Document the position parameter in apply_aspect()
* :ghpull:`23355`: Revert "Try to unbreak CI by xfailing OSX Tk tests"
* :ghpull:`23610`: TST: be more forgiving about IDing Noto
* :ghpull:`23609`: print version number when building docs
* :ghpull:`20832`: Implement multi-font embedding for PS Backend
* :ghpull:`20804`: Implement multi-font embedding for PDF Backend
* :ghpull:`23202`: MNT: Remove cached renderer from figure
* :ghpull:`23497`: Avoid gridspec in more examples
* :ghpull:`23602`: Editing "issues for new contributors"
* :ghpull:`23600`: DOC: view_init docstring for 3d axes primary view angles
* :ghpull:`23587`: BUG:datetime list starting with none
* :ghpull:`23559`: re-base of font fallback for pdf and eps output + SVG support
* :ghpull:`23557`: BLD: update the manylinux versions used
* :ghpull:`23596`: Minor cleanup of axes_grid1
* :ghpull:`23594`: Expire deprecation on passing bytes to FT2Font.set_text
* :ghpull:`23435`: Add conda env to setup instructions
* :ghpull:`23574`: Move colorbar() doc to method itself.
* :ghpull:`23584`: Bump Ubuntu to 20.04 on GitHub Actions
* :ghpull:`23561`: Clean up code in tri
* :ghpull:`23582`: Cleanup axis3d.Axis.draw
* :ghpull:`23510`: Refactor Widget tests
* :ghpull:`20718`: Circle: Build docs in parallel.
* :ghpull:`22452`: ENH: add ability to remove layout engine
* :ghpull:`23516`: warning when scatter plot color settings discarded
* :ghpull:`23577`: apply_aspect cleanups
* :ghpull:`23575`: Cleanup parasite_simple example.
* :ghpull:`23567`: Remove noop setattr_cm.
* :ghpull:`23412`: Fix dash offset bug in Patch
* :ghpull:`21756`: MNT: Clean up some UTF strings and memory autorelease
* :ghpull:`23558`: MNT: Use UTF-8 string in macosx backend
* :ghpull:`23550`: Change exception types, improve argument checking, and cleanups in mpl_toolkits
* :ghpull:`23196`: Unify set_pickradius argument
* :ghpull:`20740`: Implement Font-Fallback in Matplotlib
* :ghpull:`22566`: Add rcparam for figure label size and weight
* :ghpull:`23551`: Remove transform arguments from _iter_collection
* :ghpull:`23444`: Deduplicate common parts in LatexManager.{__init__,_setup_latex_process}
* :ghpull:`23017`: [ENH] : Provide axis('equal') for Axes3D (replace PR #22705)
* :ghpull:`22950`: Simplify definition of mathtext symbols & correctly end tokens in mathtext parsing
* :ghpull:`23409`: Provide axis('equal') for Axes3D (replaces PR #23017)
* :ghpull:`23434`: Fix array-like linewidth for 3d scatter
* :ghpull:`23500`: Move the common implementation of Axes.set_x/y/zscale to Axis.
* :ghpull:`23533`: Add tests for sankey and minor fixes
* :ghpull:`23535`: Make margins error as claimed in doc-string
* :ghpull:`23546`: Simplify impl. of functions optionally used as context managers.
* :ghpull:`23494`: Fix various issues from SonarQube
* :ghpull:`23529`: Add workflow dispatch GitHub CI
* :ghpull:`23539`: Small improvements to WebAgg example
* :ghpull:`23541`: Change doc-build CI install order
* :ghpull:`23526`: DOC: make "family" less ambiguous in FontProperties docs
* :ghpull:`23537`: Move the deprecated RendererGTK{3,4}Cairo to a single place.
* :ghpull:`23140`: [Features] Allow setting legend title alignment
* :ghpull:`23538`: Fix imprecise docs re: backend dependencies.
* :ghpull:`23532`: Add test for RGBAxes
* :ghpull:`23453`: Add more tests for mplot3d
* :ghpull:`23501`: Let Axes.clear iterate over Axises.
* :ghpull:`23469`: Inline _init_axis_artists & _init_gridlines into clear.
* :ghpull:`23475`: Add markerfacealt to pass-through arguments for error bar lines
* :ghpull:`23527`: STY: fix whitespace on an assert
* :ghpull:`23495`: Fix sgskip'd examples
* :ghpull:`23404`: Restore matplotlib.__doc__ in Sphinx docs
* :ghpull:`23507`: Add hint when More than {max_open_warning} figures have been opened
* :ghpull:`23499`: Fix outdated comment re: event handlers in test_backends_interactive.
* :ghpull:`23498`: Fix direct instantiation of webagg_core managers.
* :ghpull:`23504`: Clarify formatting of the code-for-reproduction field in bug reports.
* :ghpull:`23489`: Add missing test data to install
* :ghpull:`23482`: Mathtext spaces must be independent of font style.
* :ghpull:`23486`: Bump pypa/cibuildwheel from 2.8.0 to 2.8.1
* :ghpull:`23461`: Tweak Axes repr.
* :ghpull:`16931`: Make it easier to improve UI event metadata.
* :ghpull:`23468`: Display grid in floating axes example.
* :ghpull:`23467`: Remove old handling for factor=None in axisartist.
* :ghpull:`23443`: Try running the pgf backend off the article class.
* :ghpull:`23373`: Fix pan/zoom crashing when widget lock is unavailable
* :ghpull:`23466`: Update filename in example.
* :ghpull:`23464`: Deprecate macos close handler.
* :ghpull:`23463`: Deprecate Tick.label
* :ghpull:`23455`: Deprecate properties w_xaxis, w_yaxis, and w_zaxis
* :ghpull:`23448`: Tweak callbacks to generate pick events.
* :ghpull:`23233`: Default stem marker color follows the linecolor
* :ghpull:`23452`: Generalize Axes __repr__ to 3D
* :ghpull:`23445`: Compare thread native ids when checking whether running on main thread.
* :ghpull:`20752`: Set norms using scale names.
* :ghpull:`23438`: DOC: numpydoc-ify date Locator classes
* :ghpull:`23427`: Tweak pgf escapes.
* :ghpull:`23432`: Fixed typo in docs animation api
* :ghpull:`23420`: Clean up test_chunksize_fails()
* :ghpull:`23415`: Minor improvements to units_sample example
* :ghpull:`21339`: Added linear scaling test to Hexbin marginals
* :ghpull:`23414`: Bump pypa/cibuildwheel from 2.7.0 to 2.8.0
* :ghpull:`23413`: Combine chunk size tests into one
* :ghpull:`23403`: Small cleanup to VertexSelector.
* :ghpull:`23291`: In the new/simplified backend API, don't customize draw_if_interactive.
* :ghpull:`23350`: Fixed SVG-as-text image comparison tests.
* :ghpull:`23406`: DOC: Fix calculation of bin centers in multi-histogram
* :ghpull:`23407`: TST: Add missing warning type to pytest.warns
* :ghpull:`23402`: Link 3D animation examples to one another.
* :ghpull:`23401`: Upload wheel artifacts from the correct directory
* :ghpull:`23374`: GOV: point CoC reports at CoC steering council subcomittee mailing list
* :ghpull:`23393`: Clean up formatting of custom cmap example
* :ghpull:`23146`: Update cibuildwheel
* :ghpull:`23368`: Add a helper to generate closed paths.
* :ghpull:`20220`: DOC: add mission statement
* :ghpull:`22364`: Tweak mathtext/tex docs.
* :ghpull:`23377`: Use tick_params more often over tick iteration
* :ghpull:`22820`: [Doc] consolidate ``rect`` documentation
* :ghpull:`23371`: Default animation.convert_args to ["-layers", "OptimizePlus"].
* :ghpull:`23148`: DOC: change address to send security issues to
* :ghpull:`23365`: DOC: add new showcase example, replace gendered one
* :ghpull:`23033`: Fix issue with tex-encoding on non-Unicode platforms
* :ghpull:`23358`: Shorten/clarify definition of extension types.
* :ghpull:`23370`: Small cleanups to animation.
* :ghpull:`23364`: Rename/change signature of PyGlyph_new.
* :ghpull:`23363`: Simplify FigureCanvas multiple inheritance init by swapping bases order.
* :ghpull:`23366`: MNT: use devel version of theme
* :ghpull:`23357`: Fixed decimal points not appearing at end of Mathtext string.
* :ghpull:`23351`: DOC/MNT install docs with dev version of sphinx theme
* :ghpull:`23349`: CI: Remove old scipy-wheels-nightly uploads to ensure space
* :ghpull:`23348`: Support multi-figure MultiCursor; prepare improving its signature.
* :ghpull:`23360`: embedding_in_tk_sgskip.py: use root.destroy
* :ghpull:`23354`: MNT: Use list comprehension
* :ghpull:`23299`: FIX/API: do not reset backend key in rc_context
* :ghpull:`23191`: ENH: add width_ratios and height_ratios to subplots
* :ghpull:`23060`: MNT: Change objective C code to Automatic Reference Counting (ARC)
* :ghpull:`23347`: Simplify/improve check for pycairo in Gtk-based backends.
* :ghpull:`23316`: DOC: improve spines crosslinking
* :ghpull:`23100`: Remove custom backend_nbagg.show(), putting logic in manager show.
* :ghpull:`23342`: FIX: make sure addFont test removes the test font
* :ghpull:`23266`: negative_linestyles kwarg in contour.py
* :ghpull:`23332`: Validate Text linespacing on input.
* :ghpull:`23336`: Remove ineffective exclusion of Arcs without parent Axes.
* :ghpull:`23341`: MNT: Use '--pytest-test-first' option for naming clarity
* :ghpull:`23337`: Remove now inexistent "datapath" rcParam from style blacklist.
* :ghpull:`22004`: Make RendererCairo auto-infer surface size.
* :ghpull:`23208`: ENH: enable stripey lines
* :ghpull:`23288`: Correct URL area with rotated texts in PDFs
* :ghpull:`23197`: Add tests for pan
* :ghpull:`22167`: Deprecate selector ``visible`` attribute
* :ghpull:`23322`: Cleanup FontProperties examples.
* :ghpull:`23321`: Tweak examples capitalization/punctuation.
* :ghpull:`23270`: Fix handling of nonmath hyphens in mathtext.
* :ghpull:`23310`: Move Cursor demo from examples/misc to examples/event_handling
* :ghpull:`23313`: Drop CSS styles that are in mpl-sphinx-theme
* :ghpull:`23314`: Don't draw invisible 3D Axes
* :ghpull:`23302`: Deprecate stem(..., use_line_collection=False)
* :ghpull:`23309`: Remove front page examples
* :ghpull:`23282`: Backport PR #22865 on branch v3.5.x (Fix issue with colorbar extend and drawedges)
* :ghpull:`23231`: Add pytest-xvfb as test dependency
* :ghpull:`23318`: No need to return OrderedDict from _gen_axes_spines.
* :ghpull:`23295`: Replace re.sub by the faster str.translate.
* :ghpull:`23300`: Modify example of "Fig Axes Customize Simple"
* :ghpull:`23014`: Improve consistency in LogLocator and LogFormatter API
* :ghpull:`23286`: Refactor URL handling in PDF backend
* :ghpull:`23065`: Fix test_image_comparison_expect_rms
* :ghpull:`23294`: Simplify binary data handling in ps backend.
* :ghpull:`23284`: DOC: Switch to HTML5 and cleanup CSS
* :ghpull:`23276`: Add get/set methods for DPI in SubFigure
* :ghpull:`23207`: Update build environment and improve test
* :ghpull:`23213`: DEV: Add name-tests-test to pre-commit hooks
* :ghpull:`23289`: Properly make Name.hexify go through a deprecation cycle.
* :ghpull:`23177`: Deprecate positional passing of most Artist constructor parameters
* :ghpull:`23287`: Minor tweaks to pdf Name.
* :ghpull:`23285`: In mathtext, replace manual caching (via ``glyphd``) by lru_cache.
* :ghpull:`23034`: Correctly read the 'style' argument while processing 'genfrac'.
* :ghpull:`23247`: Support inverted parentheses in mathtext.
* :ghpull:`23190`: Deprecate unused methods in axis.py
* :ghpull:`23219`: MNT: Rename example files with 'test' in name
* :ghpull:`23277`: MNT: Remove dead code in SVG backend
* :ghpull:`23261`: Bump actions/setup-python from 3 to 4
* :ghpull:`23264`: Changing environment.yml for it to work on Windows
* :ghpull:`23269`: MNT: Remove dead code in Colorbar
* :ghpull:`23262`: Simplify qt_compat, in particular post-removal of qt4 support.
* :ghpull:`23263`: Private helper to get requested backend without triggering resolution.
* :ghpull:`23243`: Fix spacing after mathtext operators with sub/superscripts
* :ghpull:`22839`: Fix spacing after mathtext operators with sub/superscripts
* :ghpull:`23256`: DOC: Add note about Inkscape install on Windows
* :ghpull:`23258`: DOC: remove Blue Book url
* :ghpull:`23255`: Add a helper to generate mathtext error strings.
* :ghpull:`23246`: Fix argument checking for set_interpolation_stage
* :ghpull:`22881`: Support not embedding glyphs in svg mathtests.
* :ghpull:`23198`: Rename ncol parameter in legend to ncols
* :ghpull:`23251`: Small simplifications to mathtext tests.
* :ghpull:`23249`: Don't allow ``r"$\left\\|\right.$"``, as in TeX.
* :ghpull:`23248`: Rename test markers
* :ghpull:`22507`: Remove *math* parameter of various mathtext internal APIs.
* :ghpull:`23192`: Add tests, improve error messages in axis/_base, and code cleanup
* :ghpull:`23241`: Fix invalid value in radio buttons example
* :ghpull:`23187`: Correct docs and use keyword arguments in _mathtext.py
* :ghpull:`23045`: MNT: Merge locally defined test marks
* :ghpull:`22289`: ENH: compressed layout
* :ghpull:`23237`: Expire BoxStyle._Base deprecation.
* :ghpull:`23225`: DOC: Fix version switcher links to documentation
* :ghpull:`23221`: DOC: recommend numpy random number generator class
* :ghpull:`23223`: Changed offset reference, add small doc
* :ghpull:`23215`: DOC: link the transforms tutorial from the module
* :ghpull:`23201`: Rework tricontour and tricontourf documentation
* :ghpull:`23013`: Add tests for date module
* :ghpull:`23188`: Mnt new default dates
* :ghpull:`22745`: MNT: Don't require renderer for window_extent and tightbbox
* :ghpull:`23077`: MNT: Remove keyword arguments to gca()
* :ghpull:`23182`: Simplify webagg blitting.
* :ghpull:`23181`: Init FigureCanvasAgg._lastKey in ``__init__``.
* :ghpull:`23175`: Point the version switcher to a name listed in switcher.json
* :ghpull:`22669`: Cleanup documentation generation for pyplot
* :ghpull:`22519`: fix markevery plot option with nans in data
* :ghpull:`21584`: Move towards having get_shared_{x,y}_axes return immutable views.
* :ghpull:`23170`: ENH: update ticks when requesting labels
* :ghpull:`23169`: DOC: Migrate to sphinx-design
* :ghpull:`23180`: Improve docstring of triplot() and PatchCollection
* :ghpull:`23153`: Restore accidentally removed pytest.ini and tests.py.
* :ghpull:`23166`: Deprecate passing most Legend arguments positionally
* :ghpull:`23165`: DOCS Fix a few typos
* :ghpull:`23167`: DOCS fix typo
* :ghpull:`23062`: Add stackplot to plot types listing
* :ghpull:`23161`: Added my (open access) book
* :ghpull:`23141`: Minor fix for astropy units support broken in earlier PR
* :ghpull:`23156`: No longer call draw_if_interactive in parasite_axes.
* :ghpull:`23150`: DOC fix typo
* :ghpull:`23149`: DOCS remove duplicate text
* :ghpull:`23145`: Fix format error in switcher.json
* :ghpull:`21755`: MNT: Clean up macosx backend set_message
* :ghpull:`23128`: DOCS Fix typos
* :ghpull:`23130`: Drop pytest warning config in nightly tests
* :ghpull:`23135`: Unpin coverage again
* :ghpull:`23133`: Make module deprecation messages consistent
* :ghpull:`23134`: Remove newline from start of deprecation warnings
* :ghpull:`22964`: Fix spelling errors
* :ghpull:`22929`: Handle NaN in bar labels and error bars
* :ghpull:`23093`: MNT: Removing 3.4 deprecations
* :ghpull:`23090`: Derive new_figure_manager from FigureCanvas.new_manager.
* :ghpull:`23099`: Remove unneeded cutout for webagg in show().
* :ghpull:`23097`: Tweak check for IPython pylab mode.
* :ghpull:`23088`: Improve error for invalid format strings / misspelled data keys.
* :ghpull:`23092`: Ensure updated monkey-patching of sphinx-gallery EXAMPLE_HEADER
* :ghpull:`23087`: Fix width/height inversion in dviread debug helper.
* :ghpull:`23089`: Normalize tk load failures to ImportErrors.
* :ghpull:`23091`: Move test that fig.add_axes() needs parameters
* :ghpull:`23067`: more explicit in windows doc build instructions
* :ghpull:`23081`: MNT: Deprecate date_ticker_factory
* :ghpull:`23079`: MNT: Remove key_press and button_press from FigureManager
* :ghpull:`23076`: MNT: Remove positional argument handling in LineCollection
* :ghpull:`23078`: MNT: Remove deprecated axis.cla()
* :ghpull:`23054`: Slightly simplify tcl/tk load in extension.
* :ghpull:`23073`: MNT: Remove dummy_threading because threading is always available
* :ghpull:`22405`: DOC: put the gallery keywords in the meta tag
* :ghpull:`23071`: Fix installing contourpy on CI
* :ghpull:`23068`: Slight refactor of _c_internal_utils to linewrap it better.
* :ghpull:`23070`: Pathlibify autotools invocation in build.
* :ghpull:`22755`: Maybe run autogen as part of freetype install
* :ghpull:`23063`: doc: mathtext example: use axhspan() instead of fill_between() for backdrop rectangle shading
* :ghpull:`23055`: Cleanup Annotation.update_position.
* :ghpull:`22567`: Use contourpy for quad contour calculations
* :ghpull:`22801`: TST: fully parameterize test_lazy_linux_headless
* :ghpull:`22180`: ENH: Use rcParams savefig.directory on macosx backend
* :ghpull:`23048`: Add rrulewrapper to docs
* :ghpull:`23047`: Fix issue with hist and float16 data
* :ghpull:`23044`: Fix missing section header for nightly builds
* :ghpull:`23029`: Demonstrate both usetex and non-usetex in demo_text_path.py.
* :ghpull:`23038`: Factor out errorevery parsing for 2D and 3D errorbars.
* :ghpull:`23036`: Suppress traceback chaining for tex subprocess failures.
* :ghpull:`23037`: Suppress exception chaining in FontProperties.
* :ghpull:`23020`: Add test to close legend issue
* :ghpull:`23031`: Specify that style files are utf-8.
* :ghpull:`22991`: Enable ``plt.sca`` on subfigure's axes
* :ghpull:`23030`: DOC: Fix charset declaration in redirects
* :ghpull:`23022`: Fix some possible encoding issues for non-utf8 systems.
* :ghpull:`23023`: Bump docker/setup-qemu-action from 1 to 2
* :ghpull:`23024`: DOC: do not suggest to sudo pip install Matplotlib
* :ghpull:`23018`: Fix typo in font family
* :ghpull:`22627`: ENH: rect for constrained_layout
* :ghpull:`22891`: Font example monospace
* :ghpull:`23006`: docs: add subplot-mosaic string compact notation
* :ghpull:`23009`: Fixed installation guide command typo
* :ghpull:`22926`: Fix RangeSlider for same init values #22686
* :ghpull:`22989`: Merge v3.5.x back into main
* :ghpull:`22993`: STY: Fix typos in colormap
* :ghpull:`22777`: DEV: Add codespell to pre-commit hooks
* :ghpull:`22940`: Fixed dpi bug in rainbow text example
* :ghpull:`22298`: MNT: Remove cmap_d colormap access
* :ghpull:`22387`: Add a registry for color sequences
* :ghpull:`21594`: Document text alignment
* :ghpull:`22967`: TST: Add some tests for QuadMesh contains function
* :ghpull:`22936`: ENH: Add full-screen toggle to the macosx backend
* :ghpull:`22886`: MNT: remove mpl_toolkits.axes_grid
* :ghpull:`22952`: Make MarkerStyle immutable
* :ghpull:`22953`: MNT: Move set_cursor to the FigureCanvas
* :ghpull:`18854`: Standardize creation of FigureManager from a given FigureCanvas class.
* :ghpull:`22925`: Standardize creation of FigureManager from a given FigureCanvas class.
* :ghpull:`22875`: Remove Forward definitions where possible.
* :ghpull:`22928`: ENH: Add option to disable raising the window for macosx
* :ghpull:`22912`: DOC: Better doc of colors
* :ghpull:`22931`: BUG: Fix regression with ls=(0, ())
* :ghpull:`22909`: FIX: skip sub directories when finding fonts on windows
* :ghpull:`22911`: Clarify docstring of [un]install_repl_displayhook()
* :ghpull:`22919`: CI: Add concurrency skips for GH Actions
* :ghpull:`22899`: Fix documentation markup issues
* :ghpull:`22906`: Clarify logic for repl displayhook.
* :ghpull:`22892`: Remove support for IPython<4.
* :ghpull:`22896`: Remove python-dateutil as test requirement
* :ghpull:`22885`: Deprecate two-layered backend_pdf.Op enum.
* :ghpull:`22883`: Tweak argument checking in tripcolor().
* :ghpull:`22884`: Missing ``f`` prefix on f-strings fix
* :ghpull:`22877`: Small cleanups to mathtext.
* :ghpull:`21374`: Snap selectors
* :ghpull:`22824`: Remove some unnecessary extra boundaries for colorbars with extensions.
* :ghpull:`21448`: Use named groups in mathtext parser.
* :ghpull:`22609`: Improve usability of dviread.Text by third parties.
* :ghpull:`22809`: STY: Apply pre-commit hooks to codebase
* :ghpull:`22730`: Fix removed cross-references
* :ghpull:`22857`: Slightly simplify twin axes detection in MEP22 zoom.
* :ghpull:`22813`: MNT: Deprecate figure callbacks
* :ghpull:`22802`: MNT: make Axes.cla an alias for Axes.clear in all cases
* :ghpull:`22855`: Remove non-needed remove_text=False.
* :ghpull:`22854`: TST: Avoid floating point errors in asinh ticker
* :ghpull:`22850`: Simplify tick creation
* :ghpull:`22841`: Fix Tk error when updating toolbar checkbutton images
* :ghpull:`22707`: Proposed ENH: Allow user to turn off breaking of streamlines in streamplot (rebased)
* :ghpull:`22826`: Bump actions/upload-artifact from 2 to 3
* :ghpull:`22825`: Bump codecov/codecov-action from 2 to 3
* :ghpull:`22821`: Use bool for bool keyword arguments
* :ghpull:`22815`: Fix pickling of globally available, dynamically generated norm classes.
* :ghpull:`22702`: Doc tweak transform tutorial
* :ghpull:`22613`: DOC: Add links to explicit vs implicit API everywhere "OO" is used
* :ghpull:`22712`: Use repr in error messages
* :ghpull:`22794`: Fix ps export of colored hatches with no linewidth
* :ghpull:`22797`: Deprecate functions in backends
* :ghpull:`22608`: Axes.inset_axes: enable Axes subclass creation
* :ghpull:`22795`: Replace "marker simplification" by "marker subsampling" in docs.
* :ghpull:`22768`: Fix inkscape tests
* :ghpull:`22791`: Tweak _ConverterError reporting.
* :ghpull:`22447`: Improve bar_label annotation
* :ghpull:`22710`: Fix the error- TypeError: 'float' object is not iterable
* :ghpull:`22444`: Revert "CI: skip test to work around gs bug"
* :ghpull:`22785`: CI: Update weekly dependency test job
* :ghpull:`22784`: Fix 'misspelled' transform variable
* :ghpull:`22778`: Fix LaTeX formatting in examples
* :ghpull:`22779`: Improve mlab documentation (and example)
* :ghpull:`22759`: MNT: Skip existing wheels during nightly wheel upload
* :ghpull:`22751`: BLD: do not put an upper bound on pyparsing
* :ghpull:`22752`: DOC: Correct nightly wheels pip install command
* :ghpull:`22742`: Fix deprecation of backend_tools.ToolBase.destroy
* :ghpull:`22725`: Move towards making texmanager stateless.
* :ghpull:`22734`: Added clim support to tripcolor
* :ghpull:`22733`: CI: Add GHA workflow to upload nightly wheels
* :ghpull:`21637`: Also upload a subset of nightly wheels
* :ghpull:`22698`: Correct cross-references in documentation
* :ghpull:`22263`: DOC: condense version switcher
* :ghpull:`22361`: Revert datetime usetex ticklabels to use default tex font.
* :ghpull:`22721`: Small style fixes.
* :ghpull:`22356`: Cleanup tripcolor()
* :ghpull:`22360`: Let TeX handle multiline strings itself.
* :ghpull:`22418`: Deprecate auto-removal of overlapping Axes by plt.subplot{,2grid}.
* :ghpull:`22722`: Rename confusingly-named cm_fallback.
* :ghpull:`22697`: Deprecate in testing.decorators
* :ghpull:`22556`: Add text.parse_math rcParams
* :ghpull:`22163`: Change colour of Tk toolbar icons on dark backgrounds
* :ghpull:`22704`: Small simplification to textpath.
* :ghpull:`22498`: TST: increase coverage on tk tests
* :ghpull:`21425`: Make Axis3D constructor signature closer to the one of 2D axis.
* :ghpull:`22665`: Improve error message for incorrect color string
* :ghpull:`22685`: Rewrite plot format detection from sphinx build target
* :ghpull:`22670`: Update deprecated vmImage 'vs2017-win2016' in azure pipelines
* :ghpull:`22503`: Deprecate backend_qt.qApp.
* :ghpull:`22683`: Add missing space before : for parameters
* :ghpull:`22591`: Fix Path/str-discrepancy in FontManager.addpath and improve documentation
* :ghpull:`22680`: Bump actions/cache from 2 to 3
* :ghpull:`22659`: Add description on quiver head parameters
* :ghpull:`22668`: Raise on missing closing quotes in matplotlibrc
* :ghpull:`22675`: Tweak colorbar_placement example.
* :ghpull:`22276`: Merge "Scatter Symbol" and "Scatter Custom Symbol" examples
* :ghpull:`22658`: Remove reference to now-deleted reminder note.
* :ghpull:`22652`: Update documentation example and fix See also
* :ghpull:`22587`: Refactor handling of tick and ticklabel visibility in Axis.clear()
* :ghpull:`22148`: MNT: Deprecate ``docstring``
* :ghpull:`22170`: Add example to polygon selector docstring showing how to set vertices programmatically
* :ghpull:`22650`: Fix new leak in ft2font introduced in #22604
* :ghpull:`22644`: FIX: Flush events after closing figures in macosx backend
* :ghpull:`22643`: Suppress exception chaining in colormap lookup.
* :ghpull:`22639`: ENH: MacOSX backend to use sRGB instead of GenericRGB colorspace
* :ghpull:`22509`: Simplifications to ToolManager.{add,remove}_tool.
* :ghpull:`22633`: DOC: remove space in directive.
* :ghpull:`22631`: Add space between individual transform components in svg output.
* :ghpull:`22523`: MNT: Use a context manager to change the norm in colorbar code
* :ghpull:`22615`: FIX: Change get_axis_map to axis_map now
* :ghpull:`22508`: Move tracking of autoscale status to Axis.
* :ghpull:`22547`: Small cleanups around TexManager usage.
* :ghpull:`22511`: Remove redundant rcParam-lookup in patches
* :ghpull:`22516`: Expire deprecations in backends
* :ghpull:`22612`: Updated grammar to reflect more common usage of output vs outputted in animation.py
* :ghpull:`22589`: Support quoted strings in matplotlibrc
* :ghpull:`22604`: MNT: Fix types in C-code to reduce warnings
* :ghpull:`22610`: Fix alternative suggestion in epoch2num() deprecation
* :ghpull:`22554`: Prepare for making create_dummy_axis not necessary.
* :ghpull:`22607`: ENH: Add dark/light mode theme to the buttons
* :ghpull:`21790`: FIX: Update blitting and drawing on the macosx backend
* :ghpull:`22175`: FIX: Update macosx animation handling
* :ghpull:`22569`: Require non-zero dash value
* :ghpull:`22544`: Correct paper sizes
* :ghpull:`20470`: Issues warnings for legend handles without handlers
* :ghpull:`22558`: MNT: Simplify imports
* :ghpull:`22580`: fix doc for annotation_clip parameter
* :ghpull:`22581`: DOC: fix various typos
* :ghpull:`22573`: Bump actions/setup-python from 2 to 3
* :ghpull:`22568`: Rename qhull source to _qhull_wrapper.cpp.
* :ghpull:`22561`: FIX: Handle stopped animation figure resize
* :ghpull:`22562`: TST: Add a frame test for animations
* :ghpull:`22514`: Expire deprecations in cbook.deprecation
* :ghpull:`22555`: Use picklable callbacks for DraggableBase.
* :ghpull:`22552`: Tweak dependency checking in doc/conf.py.
* :ghpull:`22550`: Require sphinx>=3 & numpydoc>=1.0 for building docs.
* :ghpull:`22539`: Deprecate toplevel mpl.text.get_rotation; normalize rotations early.
* :ghpull:`22502`: Cleanup unused imports and variables in backends
* :ghpull:`20071`: Document, test, and simplify impl. of auto_adjustable_area.
* :ghpull:`22366`: Deprecation removal/updates in axes3d
* :ghpull:`22484`: Simplify the internal API to connect picklable callbacks.
* :ghpull:`22417`: Support passing rgbaFace as an array to agg's draw_path.
* :ghpull:`22412`: Turn _get_axis_map() into a property and remove _get_axis_list()
* :ghpull:`22486`: Expire deprecations in lines and patches
* :ghpull:`22512`: Increase coverage
* :ghpull:`22504`: Simplify FontProperties init.
* :ghpull:`22497`: Remove entries of MathTextParser._backend_mapping deprecated in 3.4.
* :ghpull:`22487`: Don't key MathTextParser cache off a mutable FontProperties.
* :ghpull:`22468`: Turn _mathtext.ship into a plain function.
* :ghpull:`22490`: Deprecate unused, untested Affine2D.identity().
* :ghpull:`22491`: Linewrap setupext to 79 character lines.
* :ghpull:`22488`: Some more maintenance for mathtext internal implementation.
* :ghpull:`22485`: Change string representation of AxesImage
* :ghpull:`22240`: Add minimum macosx version
* :ghpull:`22480`: Remove _point_size_reduction.
* :ghpull:`22204`: Cleanup _mathtext internal API
* :ghpull:`22469`: Improve readability of mathtext internal structures.
* :ghpull:`22477`: Un-pyplot some examples which were already explicitly referencing axes.
* :ghpull:`22467`: Small cleanup to font handling in agg.
* :ghpull:`21178`: Add asinh axis scaling (*smooth* symmetric logscale)
* :ghpull:`22411`: Move cbook._define_aliases() to _api.define_aliases()
* :ghpull:`22465`: Deprecate unused AddList.
* :ghpull:`22451`: Clarify error message for bad keyword arguments.
* :ghpull:`21267`: Cleanup AnnotationBbox.
* :ghpull:`22464`: Small improvements related to radar_chart example.
* :ghpull:`22421`: Make most params to figure()/Figure() kwonly.
* :ghpull:`22457`: Copy arrowprops argument to FancyAnnotationBbox.
* :ghpull:`22454`: move ``_toolbar_2`` from webagg_core to webagg
* :ghpull:`22413`: Remove some trivial private getters/setters in axisartist
* :ghpull:`21634`: TST: Add future dependency tests as a weekly CI job
* :ghpull:`22079`: Share FigureManager class between gtk3 and gtk4.
* :ghpull:`22440`: Clarify warning about labels with leading underscores.
* :ghpull:`17488`: Make error message explicit in legend.py
* :ghpull:`22453`: Simplify impl. of polar limits setting API.
* :ghpull:`22449`: Small cleanup to quiver.
* :ghpull:`22415`: Make emit and auto args of set_{x,y,z}lim keyword only.
* :ghpull:`22422`: Deprecate backend_ps.convert_psfrags.
* :ghpull:`22194`: Drop support for Python 3.7
* :ghpull:`22234`: Partial fix for grid alpha
* :ghpull:`22433`: Fix ambiguous link targets in docs.
* :ghpull:`22420`: Update plt.figure() docstring.
* :ghpull:`22388`: Make signature of Axes.annotate() more explicit.
* :ghpull:`22419`: Remove "Matplotlib version" from docs issue template
* :ghpull:`22423`: Avoid indiscriminate glob-remove in xpdf_distill.
* :ghpull:`22406`: [DOC]: Removed a redundant 'The'
* :ghpull:`21442`: Factor out common limits handling for x/y/z axes.
* :ghpull:`22397`: Axes capitalization in widgets and axes3d
* :ghpull:`22394`: Tweak Axes3D docstrings that refer to 2D plotting methods.
* :ghpull:`22383`: TST: fix doc build
* :ghpull:`21877`: DOC: attempt to explain the main different APIs
* :ghpull:`21238`: Raise when unknown signals are connected to CallbackRegistries.
* :ghpull:`22345`: MNT: make layout deprecations pending
* :ghpull:`21597`: FIX: Remove the deepcopy override from transforms
* :ghpull:`22370`: Replace tabs with spaces in C code.
* :ghpull:`22371`: Corrected a mistake in comments (Issue #22369)
* :ghpull:`21352`: Refactor hexbin().
* :ghpull:`19214`: Improve autoscaling for high order Bezier curves
* :ghpull:`22268`: Deprecated is_decade and is_close_to_int
* :ghpull:`22359`: Slightly refactor TeX source generation.
* :ghpull:`22365`: Remove deprecated ``MovieWriter.cleanup``
* :ghpull:`22363`: Properly capitalize "Unicode".
* :ghpull:`22025`: Deprecate various custom FigureFrameWx attributes/methods.
* :ghpull:`21391`: Reuse imsave()'s background-blending code in FigureCanvasAgg.print_jpeg.
* :ghpull:`22026`: Simplify wxframe deletion.
* :ghpull:`22351`: Fix "trailing" whitespace in C docstrings.
* :ghpull:`22342`: Docstrings for _qhull.
* :ghpull:`21836`: Slightly shorten ft2font init.
* :ghpull:`21962`: Privatize various internal APIs of backend_pgf.
* :ghpull:`22114`: Rewrite AxesStack independently of cbook.Stack.
* :ghpull:`22332`: Let TransformedPatchPath inherit most functionality from TransformedPath.
* :ghpull:`22292`: Cleanup Axis._translate_tick_kw
* :ghpull:`22339`: wx.App() should be init'ed in new_figure_manager_given_figure
* :ghpull:`22315`: More standardization of floating point slop in mpl_toolkits.
* :ghpull:`22337`: DOC: More cleanup axes -> Axes
* :ghpull:`22323`: Replace sole use of maxdict by lru_cache.
* :ghpull:`22229`: FIX: make safe to add / remove artists during ArtistList iteration
* :ghpull:`22196`: ``dates`` classes and functions support ``tz`` both as string and ``tzinfo``
* :ghpull:`22161`: Add box when setting ``PolygonSelector.verts``
* :ghpull:`19368`: Raise warning and downsample if data given to _image.resample is too large
* :ghpull:`22250`: Unify toolbar init across backends.
* :ghpull:`22304`: Added tests for ContourSet.legend_elements
* :ghpull:`21583`: Add pre-commit config and dev instructions
* :ghpull:`21547`: Custom cap widths in box and whisker plots in bxp() and boxplot()
* :ghpull:`20887`: Implement a consistent behavior in TkAgg backend for bad blit bbox
* :ghpull:`22317`: Rename outdated seaborn styles.
* :ghpull:`22271`: Rework/fix Text layout cache.
* :ghpull:`22097`: In mpl_toolkits, use the same floating point slop as for standard ticks.
* :ghpull:`22295`: Display bad format string in error message.
* :ghpull:`22287`: Removed unused code and variables
* :ghpull:`22244`: MNT: colorbar locators properties
* :ghpull:`22270`: Expanded documentation of Axis.set_ticks as per discussion in issue #22262
* :ghpull:`22280`: Simplify FontProperties.copy().
* :ghpull:`22174`: Give the Tk toolbar buttons a flat look
* :ghpull:`22046`: Add the ability to change the focal length of the camera for 3D plots
* :ghpull:`22251`: Colorbar docstring reorg
* :ghpull:`21933`: MNT: privatize colorbar attr
* :ghpull:`22258`: DOC: fix version switcher
* :ghpull:`22261`: DOC: fix switcher json
* :ghpull:`22154`: Add some tests for minspan{x,y} in RectangleSelector
* :ghpull:`22246`: DOC: add dropdown
* :ghpull:`22133`: Deprecated ``afm``, ``fontconfig_pattern``, and ``type1font``
* :ghpull:`22249`: DOC: More capitalization of Axes
* :ghpull:`22021`: Ensure that all toolbar (old/new) subclasses can be init'ed consistently
* :ghpull:`22213`: Improve ft2font error reporting.
* :ghpull:`22245`: Deprecate cleared kwarg to get_renderer.
* :ghpull:`22239`: Fix typos
* :ghpull:`22216`: turn off the grid after creating colorbar axes
* :ghpull:`22055`: FIX: Return value instead of enum in get_capstyle/_joinstyle
* :ghpull:`22228`: Remove some unnecessary getattrs.
* :ghpull:`20426`: ENH: Layout engine
* :ghpull:`22224`: Trivial doc fix to annotations tutorial.
* :ghpull:`21894`: Jointly track x and y in PolygonSelector.
* :ghpull:`22205`: Bump minimum NumPy to 1.19
* :ghpull:`22203`: Factor out underline-thickness lookups in mathtext.
* :ghpull:`22189`: DOC: Add hatch API to reference
* :ghpull:`22084`: Clean up 3d plot box_aspect zooming
* :ghpull:`22098`: Expire axes_grid1/axisartist deprecations.
* :ghpull:`22013`: Use standard toolbar in wx.
* :ghpull:`22160`: Removed unused variables etc.
* :ghpull:`22179`: FIX: macosx check case-insensitive app name
* :ghpull:`22157`: Improved coverage of mathtext and removed unused code
* :ghpull:`21781`: Use a fixture to get widget testing axes
* :ghpull:`22140`: Ensure log formatters use Unicode minus
* :ghpull:`21342`: Fix drawing animated artists changed in selector callback
* :ghpull:`22134`: Deprecated ``tight_bbox`` and ``tight_layout`` modules
* :ghpull:`21965`: Switch transOffset to offset_transform.
* :ghpull:`22145`: Make Tk windows use the same icon as other backends
* :ghpull:`22107`: Expire mathttext-related deprecations
* :ghpull:`22139`: FIX: width/height were reversed in macosx rectangle creation
* :ghpull:`22123`: Deprecate accepting arbitrary parameters in some get_window_extent() methods
* :ghpull:`22122`: Hint at draw_without_rendering() in Text.get_window_extent
* :ghpull:`22120`: Drop dependency on scipy in the docs.
* :ghpull:`22063`: FIX: Autoposition title when yaxis has offset
* :ghpull:`22119`: Micro-optimize skew().
* :ghpull:`22109`: Remove unnecessary null checks in macosx.m, and some more maintenance
* :ghpull:`21977`: Add corner coordinate helper methods to Ellipse/Rectangle
* :ghpull:`21830`: Add option of bounding box for PolygonSelector
* :ghpull:`22115`: Turn _localaxes into a plain list.
* :ghpull:`22108`: Micro-optimize rotation transform.
* :ghpull:`22043`: Cleanup differential equations examples.
* :ghpull:`22080`: Simple style(ish) fixes.
* :ghpull:`22110`: Right-aligned status text in backends
* :ghpull:`21873`: DOC: Update and consolidate Custom Tick Formatter for Time Series example
* :ghpull:`22112`: Fix a small typo
* :ghpull:`20117`: Very soft-deprecate AxesDivider.new_{horizontal,vertical}.
* :ghpull:`22034`: Update lines_with_ticks_demo.py
* :ghpull:`22102`: DOC: rename usage tutorial to quick_start
* :ghpull:`19228`: Validate text rotation in setter
* :ghpull:`22081`: Expire colorbar-related deprecations.
* :ghpull:`22008`: Added color keyword argument to math_to_image
* :ghpull:`22058`: Remove exprired mplot3d deprecations for 3.6
* :ghpull:`22073`: DOC: Add new tutorial to external resources.
* :ghpull:`22054`: MNT: Set CapStyle member names automatically
* :ghpull:`22061`: De-duplicate mplot3D API docs
* :ghpull:`22075`: Remove unnecessary ``.figure`` qualifier in docs.
* :ghpull:`22051`: Make required_interactive_framework required on FigureCanvas.
* :ghpull:`22050`: Deprecate the noop, unused FigureCanvasBase.resize.
* :ghpull:`22030`: Add explanatory comments to "broken" horizontal bar plot example
* :ghpull:`22001`: Fix:    [Bug]: triplot with 'ls' argument yields TypeError #21995
* :ghpull:`22045`: Fill in missing Axes3D box_aspect argument docstring
* :ghpull:`22042`: Keep FontEntry helpers private.
* :ghpull:`21042`: Make rcParams.copy() return a new RcParams instance.
* :ghpull:`22032`: flipy only affects the drawing of texts, not of images.
* :ghpull:`21993`: Added docstring to rrulewrapper class
* :ghpull:`21935`: Significantly improve tight layout performance for cartopy axes
* :ghpull:`22000`: Some gtk cleanups.
* :ghpull:`21983`: Simplify canvas class control in FigureFrameWx.
* :ghpull:`21985`: Slightly tighten the _get_layout_cache_key API.
* :ghpull:`22020`: Simplify wx _print_image.
* :ghpull:`22010`: Fix syntax highlighting in contrib guide.
* :ghpull:`22003`: Initialize RendererCairo.{width,height} in constructor.
* :ghpull:`21992`: Use _make_classic_style_pseudo_toolbar more.
* :ghpull:`21916`: Fix picklability of make_norm_from_scale norms.
* :ghpull:`21981`: FigureCanvasCairo can init RendererCairo; kill RendererCairo subclasses.
* :ghpull:`21986`: InvLogTransform should only return masked arrays for masked inputs.
* :ghpull:`21991`: PEP8ify wx callback names.
* :ghpull:`21975`: DOC: remove experimental tag from CL
* :ghpull:`21989`: Autoinfer norm bounds.
* :ghpull:`21980`: Removed loaded modules logging
* :ghpull:`21982`: Deprecate duplicated FigureManagerGTK{3,4}Agg classes.
* :ghpull:`21963`: Clarify current behavior of draw_path_collection.
* :ghpull:`21974`: Reword inset axes example.
* :ghpull:`21835`: Small improvements to interactive examples
* :ghpull:`21050`: Store dash_pattern as single attribute, not two.
* :ghpull:`21557`: Fix transparency when exporting to png via pgf backend.
* :ghpull:`21904`: Added _repr_html_ for fonts
* :ghpull:`21696`: Use cycling iterators in RendererBase.
* :ghpull:`21955`: Refactor common parts of ImageMagick{,File}Writer.
* :ghpull:`21952`: Clarify coordinates for RectangleSelector properties
* :ghpull:`21964`: Fix some more missing references.
* :ghpull:`21516`: Make _request_autoscale_view more generalizable to 3D.
* :ghpull:`21947`: Slightly cleanup RendererBase docs.
* :ghpull:`21961`: Privatize various internal APIs of backend_pgf.
* :ghpull:`21956`: Remove tests for avconv animation writers.
* :ghpull:`21954`: DOC: Move Animation and MovieWriter inheritance diagrams ...
* :ghpull:`21780`: Add a click_and_move widget test helper
* :ghpull:`21941`: Merge branch v3.5.x into main
* :ghpull:`21936`: Small ``__getstate__`` cleanups.
* :ghpull:`21939`: Update comment re: register_at_fork.
* :ghpull:`21910`: Fold _rgbacache into _imcache.
* :ghpull:`21921`: Clean up RectangleSelector move code
* :ghpull:`21925`: Drop labelling from PR welcome action
* :ghpull:`14930`: Set Dock icon on the macosx backend
* :ghpull:`21920`: Improve square state calculation in RectangleSelector
* :ghpull:`21919`: Fix use_data_coordinates docstring
* :ghpull:`21881`: Add a PolygonSelector.verts setter
* :ghpull:`20839`: Fix centre and square state and add rotation for rectangle selector
* :ghpull:`21874`: DOC: Add Date Tick Locators and Formatters example
* :ghpull:`21799`: Added get_font_names() to fontManager
* :ghpull:`21871`: DOC: Code from markevery_prop_cycle moved to test.
* :ghpull:`21395`: Expire _check_savefig_extra_args-related deprecations.
* :ghpull:`21867`: Remove unused bbox arg to _convert_agg_to_wx_bitmap.
* :ghpull:`21868`: Use partialmethod for better signatures in backend_ps.
* :ghpull:`21520`: Shorten some inset_locator docstrings.
* :ghpull:`21737`: Update the "Rotating a 3D plot" gallery example to show all 3 rotation axes
* :ghpull:`21851`: Re-order a widget test function
* :ghpull:`10762`: Normalization of elevation and azimuth angles for surface plots
* :ghpull:`21426`: Add ability to roll the camera in 3D plots
* :ghpull:`21822`: Replace NSDictionary by switch-case.
* :ghpull:`21512`: MNT: Add modifier key press handling to macosx backend
* :ghpull:`21784`: Set macOS icon when using Qt backend
* :ghpull:`21748`: Shorten PyObjectType defs in macosx.m.
* :ghpull:`21809`: MNT: Turn all macosx warnings into errors while building
* :ghpull:`21792`: Fix missing return value in closeButtonPressed.
* :ghpull:`21767`: Inherit many macos backend docstrings.
* :ghpull:`21766`: Don't hide build log on GHA.
* :ghpull:`21728`: Factor out some macosx gil handling for py-method calls from callbacks.
* :ghpull:`21754`: Update gitattributes so that objc diffs are correctly contextualized.
* :ghpull:`21752`: Add a helper for directly output pdf streams.
* :ghpull:`21750`: Don't sort pdf dicts.
* :ghpull:`21745`: DOC: Clarify Coords Report Example
* :ghpull:`21746`: Fix/add docstring signatures to many C++ methods.
* :ghpull:`21631`: DOC: change gridspec tutorial to arranging_axes tutorial
* :ghpull:`21318`: FIX: better error message for shared axes and axis('equal')
* :ghpull:`21519`: mark_inset should manually unstale axes limits before drawing itself.
* :ghpull:`21724`: Fix copyright date with SOURCE_DATE_EPOCH set
* :ghpull:`21398`: FIX: logic of title repositioning
* :ghpull:`21717`: Simplify macosx toolbar init.
* :ghpull:`21690`: Whitespace/braces/#defines cleanup to macosx.
* :ghpull:`21695`: Use _api.check_shape more.
* :ghpull:`21698`: Small code cleanups and style fixes.
* :ghpull:`21529`: Delay-load keymaps in toolmanager.
* :ghpull:`21525`: Fix support for clim in scatter.
* :ghpull:`21697`: Drop non-significant zeros from ps output.
* :ghpull:`21692`: CI: Remove CI test runs from forks of matplotlib
* :ghpull:`21591`: Make ToolFullScreen a Tool, not a ToolToggle.
* :ghpull:`21677`: Simplify test for negative xerr/yerr.
* :ghpull:`21657`: Replace some image_comparisons by return-value-tests/check_figures_e…
* :ghpull:`21664`: Merge 3.5.x into main
* :ghpull:`21490`: Make Line2D copy its inputs
* :ghpull:`21639`: Skip some uses of packaging's PEP440 version for non-Python versions.
* :ghpull:`21604`: Fix centre square rectangle selector part 1
* :ghpull:`21593`: Check for images added-and-modified in a same PR
* :ghpull:`20750`: Shorten issue templates
* :ghpull:`21590`: Make gtk3 full_screen_toggle more robust against external changes.
* :ghpull:`21582`: Organize checklist in PR template
* :ghpull:`21580`: Rename/remove _lastCursor, as needed.
* :ghpull:`21567`: Removed the range parameter from the validate_whiskers function's err…
* :ghpull:`21565`: Further remove remnants of offset_position.
* :ghpull:`21542`: [ENH]: Use new style format strings for colorbar ticks
* :ghpull:`21564`: Skip invisible artists when doing 3d projection.
* :ghpull:`21558`: Various small fixes for streamplot().
* :ghpull:`21544`: Return minorticks as array, not as list.
* :ghpull:`21546`: Added links to the mosaic docs in figure and pyplot module docstrings
* :ghpull:`21545`: Turn mouseover into a mpl-style getset_property.
* :ghpull:`21537`: Remove unnecessary False arg when constructing wx.App.
* :ghpull:`21536`: Reword margins docstrings, and fix bounds on zmargin values.
* :ghpull:`21535`: typo-correction-on-line-185
* :ghpull:`21534`: Do not use space in directive calling.
* :ghpull:`21494`: Adding tutorial links for blitting in widgets.py
* :ghpull:`21407`: Stash exceptions when FT2Font closes the underlying stream.
* :ghpull:`21431`: set_ticks([single_tick]) should also expand view limits.
* :ghpull:`21444`: Make pipong example self-contained.
* :ghpull:`21392`: Add label about workflow to new contributor PRs
* :ghpull:`21440`: Install sphinx-panels along with development setup
* :ghpull:`21434`: Remove coords_flat variable
* :ghpull:`21415`: Move gui_support.macosx option to packages section.
* :ghpull:`21412`: Privatize some SVG internal APIs.
* :ghpull:`21401`: Uncamelcase some internal variables in axis.py; rename _get_tick_bboxes.
* :ghpull:`21417`: Use Bbox.unit() more.
* :ghpull:`20253`: Simplify parameter handling in FloatingAxesBase.
* :ghpull:`21379`: Simplify filename tracking in FT2Font.
* :ghpull:`21278`: Clear findfont cache when calling addfont().
* :ghpull:`21400`: Use bbox.{size,bounds,width,height,p0,...} where appropriate.
* :ghpull:`21408`: Reword annotations tutorial section titles.
* :ghpull:`21371`: Rename default branch
* :ghpull:`21389`: Log pixel coordinates in event_handling coords_demo example on terminal/console
* :ghpull:`21376`: Factor common parts of saving to different formats using pillow.
* :ghpull:`21377`: Enable tests for text path based markers
* :ghpull:`21283`: Demonstrate inset_axes in scatter_hist example.
* :ghpull:`21356`: Raise an exception when find_tex_file fails to find a file.
* :ghpull:`21362`: Simplify wording of allowed errorbar() error values
* :ghpull:`21274`: ENH: Add support to save images in WebP format
* :ghpull:`21289`: Simplify _init_legend_box.
* :ghpull:`21256`: Make image_comparison work even without the autoclose fixture.
* :ghpull:`21343`: Fix type1font docstring markup/punctuation.
* :ghpull:`21341`: Fix trivial docstring typo.
* :ghpull:`21301`: Simplify ``Colormap.__call__`` a bit.
* :ghpull:`21280`: Make ``Path.__deepcopy__`` interact better with subclasses, e.g. TextPath.
* :ghpull:`21266`: Fix #21101 Add validator to errorbar method
* :ghpull:`20921`: Fix problem with (deep)copy of TextPath
* :ghpull:`20914`: 19195 rotated markers
* :ghpull:`21276`: Add language about not assigning issues
* :ghpull:`20715`: Improve Type-1 font parsing
* :ghpull:`21218`: Parametrize/simplify test_missing_psfont.
* :ghpull:`21213`: Compress comments in make_image.
* :ghpull:`21187`: Deprecate error_msg_foo helpers.
* :ghpull:`21190`: Deprecate mlab.stride_windows.
* :ghpull:`21152`: Rename ``**kw`` to ``**kwargs``.
* :ghpull:`21087`: Move colormap examples from userdemo to images_contours_and_fields.
* :ghpull:`21074`: Deprecate MarkerStyle(None).
* :ghpull:`20990`: Explicit registration of canvas-specific tool subclasses.
* :ghpull:`21049`: Simplify setting Legend attributes
* :ghpull:`21056`: Deprecate support for no-args MarkerStyle().
* :ghpull:`21059`: Remove dummy test command from setup.py
* :ghpull:`21015`: Prepare for rcParams.copy() returning a new RcParams instance in the future
* :ghpull:`21021`: Factor out for_layout_only backcompat support in get_tightlayout.
* :ghpull:`21023`: Inline ToolManager._trigger_tool to its sole call site.
* :ghpull:`21005`: Test the rcParams deprecation machinery.
* :ghpull:`21010`: Avoid TransformedBbox where unneeded.
* :ghpull:`21019`: Reword custom_ticker1 example.
* :ghpull:`20995`: Deprecate some backend_gtk3 helper globals.
* :ghpull:`21004`: Remove now-unused rcParams _deprecated entries.
* :ghpull:`20986`: Make HandlerLine2D{,Compound} inherit constructors from HandlerNpoints.
* :ghpull:`20974`: Rename symbol_name to glyph_name where appropriate.
* :ghpull:`20961`: Small cleanups to math_to_image.
* :ghpull:`20957`: legend_handler_map cleanups.
* :ghpull:`20955`: Remove unused HostAxes._get_legend_handles.
* :ghpull:`20851`: Try to install the Noto Sans CJK font

Issues (202):

* :ghissue:`23827`: backend_gtk3agg.py calls set_device_scale
* :ghissue:`23560`: [Doc]: mpl_toolkits.axes_grid still mentioned as maintained
* :ghissue:`23794`: [Doc]: Version switcher broken in devdocs
* :ghissue:`23806`: [Bug]: possible regression in axis ticks handling in matplotlib 3.6.0rc2
* :ghissue:`22965`: [Bug]: triplot duplicates label legend
* :ghissue:`23807`: streamplot raises ValueError when the input is zeros
* :ghissue:`23761`: [Bug]: False positive legend handler warnings in 3.6.0.rc1
* :ghissue:`23398`: [Bug]: Newer versions of matplotlib ignore xlabel on colorbar axis
* :ghissue:`23699`: [Bug]: Bug with toolbar instantiation in notebook
* :ghissue:`23745`: [Doc]: Minor rcParams/matplotlibrc doc issues
* :ghissue:`23717`: [Bug]: AxesSubplot.get_yticks not returning the actual printed ticks
* :ghissue:`21508`: [Doc]: Create diagram to show rotation directions for 3D plots
* :ghissue:`23709`: [Bug]: colorbar with unattached mappables can't steal space
* :ghissue:`23701`: [Bug]: plt.figure(), plt.close() leaks memory
* :ghissue:`22409`: [Bug]: AttributeError: 'QResizeEvent' object has no attribute 'pos'
* :ghissue:`19609`: DeprecationWarning when changing color maps
* :ghissue:`23716`: MatplotlibDeprecationWarning removal hard-breaks seaborn in 3.6rc1
* :ghissue:`23719`: [Bug]: register_cmap deprecation message seems wrong
* :ghissue:`23707`: test_Normalize fails on aarch64/ppc64le/s390x
* :ghissue:`21107`: [MNT]: Should plt.xticks() get a minor keyword argument
* :ghissue:`23679`: [Doc]: Deprecated modules not in docs
* :ghissue:`19550`: Arc and pathpatch_2d_to_3d plots full ellipse
* :ghissue:`23329`: [Bug]: ``plt.autoscale()`` fails for partial ``Arc``
* :ghissue:`11266`: Arc patch ignoring theta1/theta2 when added to Axes via PatchCollection
* :ghissue:`4067`: 'Poly3DCollection' object has no attribute '_facecolors2d'
* :ghissue:`23622`: [MNT]: make.bat not parsing sphinxopt
* :ghissue:`23459`: [Bug]: 'Line3D' object has no attribute '_verts3d'
* :ghissue:`23653`: [Bug]: macosx subplot tool causes segfault when window closed
* :ghissue:`23660`: [Bug]: Test test_figure.py::test_subfigure_ss[png] FAILED on ppc64le
* :ghissue:`23645`: [MNT]: Python 3.11 manylinux wheels
* :ghissue:`23650`: TTF fonts loaded from file are not embedded/displayed properly when saved to pdf
* :ghissue:`23583`: [Doc]: Document the position parameter in apply_aspect()
* :ghissue:`23386`: setuptools_scm-git-archive is obsolete
* :ghissue:`23220`: [Doc]: Clarify ``offset`` parameter in linestyle
* :ghissue:`22746`: [Doc]: Document that rcParams['font.family'] can be a list
* :ghissue:`8187`: Axes doesn't have ````legends```` attribute?
* :ghissue:`23580`: [Bug]: TypeError when plotting against list of datetime.date where 0th element of list is None
* :ghissue:`15514`: Relevant methods are only documented in base classes and thus not easily discoverable
* :ghissue:`21611`: DOC: Add conda environment instructions to developers guide
* :ghissue:`23487`: [Bug]: scatter plot color settings discarded unless c given
* :ghissue:`22977`: [Bug]: offset dash linestyle has no effect in patch objects
* :ghissue:`18883`: Matplotlib would not try to apply all the font in font list to draw all characters in the given string.
* :ghissue:`22570`: [ENH]: Provide ``axis('equal')`` for ``Axes3D``.
* :ghissue:`23433`: [Bug]: array-like linewidth raises an error for scatter3D
* :ghissue:`12388`: Legend Title Left Alignment
* :ghissue:`23375`: [Bug]: markerfacecoloralt not supported when drawing errorbars
* :ghissue:`17973`: DOC: matplotlib.__doc__ not included in online docs ?
* :ghissue:`23474`: [Bug]: ``\,`` and ``\mathrm{\,}`` are not identical in Mathtext when using CM and STIX
* :ghissue:`8715`: event handlers have different signatures across backends
* :ghissue:`18271`: PGF uses the minimal document class
* :ghissue:`23324`: [Bug]: Exception not handled in widgetlock()
* :ghissue:`15710`: doc for type of tz parameter is inconsistent throughout dates.py
* :ghissue:`21165`: Hexbin marginals need a test for linear scaling
* :ghissue:`23105`: [MNT]: Deprecate per-backend customization of draw_if_interactive
* :ghissue:`23147`: [Bug]: with setuptools>=60, cannot find msbuild
* :ghissue:`23379`: [Bug]: Offset notation on y-axis can overlap with a long title
* :ghissue:`22819`: [Doc]: Make rect argument consistent in the docstrings
* :ghissue:`23172`: [Bug]: Calling matplotlib.pyplot.show() outside of matplotlib.pyplot.rc_context no longer works
* :ghissue:`23019`: [Bug]: ``UnicodeDecodeError`` when using some special and accented characters in TeX
* :ghissue:`23334`: [Doc]: Tk embedding example crashes Spyder
* :ghissue:`23298`: [Bug]: get_backend() clears figures from Gcf.figs if they were created under rc_context
* :ghissue:`21942`: [ENH]: add width/height_ratios to subplots and friends
* :ghissue:`23028`: [ENH]: contour kwarg for negative_linestyle
* :ghissue:`19223`: Certain non-hashable parameters to text() give cryptic error messages
* :ghissue:`18351`: Add the ability to plot striped lines
* :ghissue:`23205`: [Bug]: URL-area not rotated in PDFs
* :ghissue:`23268`: [Bug]: hyphen renders different length depending on presence of MathText
* :ghissue:`23308`: [Bug]: set_visible() not working for 3d projection
* :ghissue:`23296`: Set_color method for line2d object in latest document not work
* :ghissue:`22992`: [Bug]: test_image_comparison_expect_rms nondeterministic failure
* :ghissue:`23008`: [ENH]: Use ``\genfrac`` in display style?
* :ghissue:`23214`: [MNT]: Rename examples with "test" in the name
* :ghissue:`17852`: Thin space missing after mathtext operators
* :ghissue:`12078`: Inconsistency in keyword-arguments ncol/ncols, nrow/nrows
* :ghissue:`23239`: [Doc]: steps is not implemented in line styles.
* :ghissue:`23151`: [MNT]: default date limits...
* :ghissue:`9462`: Misaligned bottoms of subplots for png output with bbox_inches='tight'
* :ghissue:`21369`: [Bug]: ax.invert_xaxis() and ax.invert_yaxis() both flip the X axis
* :ghissue:`20797`: ``macosx`` cursors break with images
* :ghissue:`23084`: [TST] Upcoming dependency test failures
* :ghissue:`22910`: [Bug]: bar_label fails with nan errorbar values
* :ghissue:`23074`: [Bug]: matplotlib crashes if ``_tkinter`` doesn't have ``__file__``
* :ghissue:`23083`: [Bug]: Confusing error messages
* :ghissue:`22391`: [Doc]: Remove "keywords" line at the bottom of all examples
* :ghissue:`20202`: Daylocator causes frozen computer when used with FuncAnimation
* :ghissue:`22529`: Replace C++ quad contouring code with use of ContourPy
* :ghissue:`21710`: [ENH]: macosx backend does not respect rcParams["savefig.directory"]
* :ghissue:`21880`: [Doc]: rrulewrapper not included in API docs
* :ghissue:`22622`: [Bug]: Gaps and overlapping areas between bins when using float16
* :ghissue:`23043`: [TST] Upcoming dependency test failures
* :ghissue:`17960`: Line2D object markers are lost when retrieved from legend.get_lines() when linestyle='None'
* :ghissue:`23026`: [MNT]: Require that matplotlibrc/style files use utf-8 (or have an encoding cookie)
* :ghissue:`22947`: [Bug]: Can't use ``plt.sca()`` on axes created using subfigures
* :ghissue:`22623`: [ENH]: support rect with constrained_layout ("layout only to part of the figure")
* :ghissue:`22917`: "ab;cd" missing in subplot_mosaic tutorial
* :ghissue:`22686`: [Bug]: cannot give init value for RangeSlider widget
* :ghissue:`22740`: [MNT]: Add codespell to pre-commit hooks
* :ghissue:`22893`: rainbow text example is broken
* :ghissue:`21571`: [Doc]: Clarify text positioning
* :ghissue:`22092`: [Bug]: Configure subplots dialog freezes for TkAgg with toolmanager
* :ghissue:`22760`: [Bug]: Macosx legend picker doesn't work anymore
* :ghissue:`16369`: Call to input blocks slider input on osx with the default agg 'MacOSX'. It works fine on when TkAgg is used.
* :ghissue:`22915`: [Bug]: figure.raise_window rcParam does not work on MacOSX backend
* :ghissue:`22930`: [Bug]: Regression in dashes due to #22569
* :ghissue:`22859`: [Bug]: findSystemFonts should not look in subdirectories of C:\Windows\Fonts\
* :ghissue:`22882`: Missing ``f`` prefix on f-strings
* :ghissue:`22738`: [MNT]: make Axes.cla an alias for Axes.clear in all cases
* :ghissue:`22708`: [TST] Upcoming dependency test failures
* :ghissue:`8388`: Proposed ENH: Allow user to turn off breaking of streamlines in streamplot
* :ghissue:`20755`: [Bug]: make_norm_from_scale should create picklable classes even when used in-line.
* :ghissue:`18249`: Expand the explanation of the Object-Oriented interface
* :ghissue:`22792`: [Bug]: .eps greyscale hatching of patches when lw=0
* :ghissue:`22630`: [ENH]: enable passing of projection keyword to Axes.inset_axes
* :ghissue:`22414`: [Bug]: bar_label overlaps bars when y-axis is inverted
* :ghissue:`22726`: [Bug]: tripcolor ignores clim
* :ghissue:`21635`: [ENH]: Add a nightly wheel build
* :ghissue:`9994`: document where nightly wheels are published
* :ghissue:`22350`: [Bug]: text.usetex Vs. DateFormatter
* :ghissue:`4976`: missing imshow() subplots when using tight_layout()
* :ghissue:`22150`: [ENH]: Tool icons are hardly visible in Tk when using a dark theme
* :ghissue:`22662`: Leave color parameter empty should be fine[ENH]:
* :ghissue:`22671`: [Doc]: plot_format adaption invalidates sphinx cache
* :ghissue:`22582`: [Bug]: FontManager.addfont doesn't accept pathlib.Path of TTF font
* :ghissue:`22657`: [ENH]: vector map
* :ghissue:`16181`: The great API cleanup
* :ghissue:`22636`: [Bug]: Infinite loop when there is single double quote in matplotlibrc
* :ghissue:`22266`: [Doc]: Improve examples in documentation
* :ghissue:`11861`: Figure does not close until script finishes execution
* :ghissue:`19288`: Escape # character in matplotlibrc
* :ghissue:`22579`: [Bug]: Replacement for epoch2num behaves differently (does not accept arrays)
* :ghissue:`22605`: [Bug]: Tool contrast low with dark theme on macosx backend
* :ghissue:`17642`: bring osx backend flush_events to feature parity with other backend
* :ghissue:`19268`: Drawing the canvas does not populate ticklabels on MacOSX backend
* :ghissue:`17445`: MacOSX does not render frames in which new artists are added when blitting
* :ghissue:`10980`: Current versions cannot reproduce rotate_axes_3d_demo.py
* :ghissue:`18451`: MacOSX backend fails with animation in certain scripts
* :ghissue:`22603`: [MNT]: Replace str(n)cpy etc with safe versions (C++)
* :ghissue:`19121`: Handle and label not created for Text with label
* :ghissue:`22563`: [Doc]: annotation_clip=None not correctly documented
* :ghissue:`12528`: Empty axes on draw after blitted animation finishes
* :ghissue:`20991`: [Bug]: Error when using path effect with a PolyCollection
* :ghissue:`19563`: path_effects kwarg triggers exception on 3D scatterplot
* :ghissue:`8650`: System Error in backend_agg. (with a fix!)
* :ghissue:`20294`: ``AxesImage.__str__`` is wrong if the image does not span the full Axes.
* :ghissue:`18066`: Document minimum supported OSX version for macos backend
* :ghissue:`17018`: Add documentation about transparency of frame
* :ghissue:`22403`: [MNT]: Confusing prompt in docs issue template
* :ghissue:`8839`: mpl_connect silently does nothing when passed an invalid event type string
* :ghissue:`22343`: [MNT]: Delay (or make pending) the deprecation of set_constrained_layout/set_tight_layout
* :ghissue:`21554`: [Bug]: ``ValueError`` upon deepcopy of a ``Figure`` object
* :ghissue:`22369`: [Doc]: Incorrect comment in example code for creating adjacent subplots
* :ghissue:`19174`: connectionstyle arc3 with high rad value pushes up data interval of x-axis and y-axis.
* :ghissue:`8351`: seaborn styles make "+", "x" markers invisible; proposed workaround for shipped styles
* :ghissue:`22278`: Deprecate/remove maxdict
* :ghissue:`19276`: imshow with very large arrays not working as expected
* :ghissue:`22035`: [ENH]: Specify a custom focal length / FOV for the 3d camera
* :ghissue:`22264`: [Bug]: new constrained_layout causes axes to go invisible(?)
* :ghissue:`21774`: [MNT]: Improvements to widget tests
* :ghissue:`18722`: Consider removing AFM+mathtext support
* :ghissue:`21540`: [Bug]: cm fontset in log scale does not use Unicode minus
* :ghissue:`22062`: [Bug]: Autopositioned title overlaps with offset text
* :ghissue:`22093`: [Bug]: AttributeError: 'AxesSubplot' object has no attribute 'add_text'
* :ghissue:`22012`: [Bug]: Mouseover coordinate/value text should be right aligned
* :ghissue:`21995`: [Bug]: triplot with 'ls' argument yields TypeError
* :ghissue:`20249`: MatplotlibDeprecationWarning when updating rcparams
* :ghissue:`15781`: MatplotlibDeprecationWarning examples.directory is deprecated
* :ghissue:`13118`: No MatplotlibDeprecationWarning for default rcParams
* :ghissue:`21978`: Remove logging debug of loaded modules
* :ghissue:`11738`: pgf backend doesn't make background transparent
* :ghissue:`18039`: Add ``_repr_html_`` for fonts
* :ghissue:`21970`: [Bug]: tight layout breaks with toolbar.push_current()
* :ghissue:`14850`: No icon showing up with macosx backend
* :ghissue:`17283`: Create Date Formatter/Locator Reference
* :ghissue:`21761`: [Doc]: add how to know available fonts...
* :ghissue:`21863`: [Doc]: Remove example "prop_cycle property markevery in rcParams"
* :ghissue:`10241`: Axes3D.view_init elevation issue between 270 and 360 degrees
* :ghissue:`14453`: add third angle to view_init()
* :ghissue:`20486`: Modifier key press events not recognized on MacOSX backend
* :ghissue:`9837`: MacOS: Key modifiers deprecated
* :ghissue:`11416`: RuntimeError: adjustable='datalim' is not allowed when both axes are shared.
* :ghissue:`17711`: inset_locator.mark_inset() misplaces box connectors
* :ghissue:`20854`: [Doc]: Incorrect copyright start year at the bottom of devdocs page
* :ghissue:`21394`: [Bug]: Subplot title does not obey padding
* :ghissue:`20998`: [Bug]: ToolManager does not respect rcParams["keymap.<any>"] set after import time
* :ghissue:`7075`: Superscripts in axis label cut when saving .eps with bbox_inches="tight"
* :ghissue:`21514`: [Doc]: Error message of validate_whiskers is not updated
* :ghissue:`21532`: [Doc]: subplot_mosaic docstring should link to the tutorial
* :ghissue:`16550`: Docs: performance discussion of tight_layout
* :ghissue:`21378`: [ENH]: use new style format strings for colorbar ticks
* :ghissue:`19323`: Streamplot color mapping fails on (near-)empty array.
* :ghissue:`19559`: Axes.get_xticks() returns a numpy array but Axes.get_xticks(minor=True) returns a plain list
* :ghissue:`21526`: [Doc]: Little Typo on Introductory Tutorial
* :ghissue:`19195`: Rotate Markers in functions like plot, scatter, etcetera
* :ghissue:`21364`: [Bug]: double free when FT2Font constructor is interrupted by KeyboardInterrupt
* :ghissue:`16581`: Can't not refresh new font in running interpreter
* :ghissue:`21162`: [ENH]: saving images in webp format
* :ghissue:`18168`: The example of the testing decorator does not work.
* :ghissue:`20943`: [Bug]: Deepcopy of TextPath fails
* :ghissue:`21101`: [Bug]: Errorbars separated from markers with negative errors
* :ghissue:`17986`: MEP22 per-backend tool registration
* :ghissue:`4938`: Feature request: add option to disable mathtext parsing
* :ghissue:`11435`: plt.subplot eats my subplots
